@@ -24,22 +24,21 @@
 #include <unistd.h>
 
 int main() {
+	NotifyNotification *n;
+
 	notify_init("Basics");
 
-	NotifyHandle *n = notify_send_notification(NULL, // replaces nothing
-											   NULL,
-											   NOTIFY_URGENCY_NORMAL,
-											   "Summary", "Content",
-											   NULL, // no icon
-											   TRUE, 0,
-											   NULL, // no hints
-											   NULL, // no user data
-											   0); // no actions
+	n = notify_notification_new ("Summary", 
+                                     "Content that is very long 8374983278r32j4 rhjjfh dw8f 43jhf 8ds7 ur2389f jdbjkt h8924yf jkdbjkt 892hjfiHER98HEJIF BDSJHF hjdhF JKLH 890YRHEJHFU 89HRJKSHdd dddd ddddd dddd ddddd dddd ddddd dddd dddd ddd ddd dddd Fdd d ddddd dddddddd ddddddddhjkewdkjsjfjk sdhkjf hdkj dadasdadsa adsd asd sd saasd fadskfkhsjf hsdkhfkshfjkhsd kjfhsjdkhfj ksdhfkjshkjfsd sadhfjkhaskd jfhsdajkfhkjs dhfkjsdhfkjs adhjkfhasdkj fhdsakjhfjk asdhkjkfhd akfjshjfsk afhjkasdhf jkhsdaj hf kjsdfahkfh sakjhfksdah kfdashkjf ksdahfj shdjdh",
+                                     NULL, NULL);
+        notify_notification_set_timeout (n, 3000); //3 seconds
 
-	if (!n) {
+	if (!notify_notification_show (n, NULL)) {
 		fprintf(stderr, "failed to send notification\n");
 		return 1;
 	}
 
+	g_object_unref(G_OBJECT(n));
+
 	return 0;
 }
